ZWave-Me-WS is a websocket connection library to a ZWave-Me instance
**Usage**

To install this package use:

`pip install zwave-me-ws`

To use the connector:

```
from zwave_me_ws import ZWaveMe

api = ZWaveMe()
```

